summaryrefslogtreecommitdiff
path: root/nuttx/include/nuttx/usb/usbhost.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-01-01 15:08:18 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-01-01 15:08:18 +0000
commit0b0417e93ff7d0ffa1e17fcefb8906ebbd41bd11 (patch)
tree437759c826057f0d8ecbb2af94f5666df6802e28 /nuttx/include/nuttx/usb/usbhost.h
parent9bdb91ec537f8a7889a816cf989e6d91054effe5 (diff)
downloadnuttx-0b0417e93ff7d0ffa1e17fcefb8906ebbd41bd11.tar.gz
nuttx-0b0417e93ff7d0ffa1e17fcefb8906ebbd41bd11.tar.bz2
nuttx-0b0417e93ff7d0ffa1e17fcefb8906ebbd41bd11.zip
Misc debug fixes
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@3227 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include/nuttx/usb/usbhost.h')
-rw-r--r--nuttx/include/nuttx/usb/usbhost.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/nuttx/include/nuttx/usb/usbhost.h b/nuttx/include/nuttx/usb/usbhost.h
index 18753e1b8..9d7919839 100644
--- a/nuttx/include/nuttx/usb/usbhost.h
+++ b/nuttx/include/nuttx/usb/usbhost.h
@@ -206,7 +206,7 @@
* Input Parameters:
* drvr - The USB host driver instance obtained as a parameter from the call to
* the class create() method.
* funcno - The USB address of the function containing the endpoint that EP0
* controls
* mps (maxpacketsize) - The maximum number of bytes that can be sent to or
* received from the endpoint in a single data packet
@@ -220,7 +220,7 @@
*
************************************************************************************/
-#define DRVR_EP0CONFIGURE(drvr,funcno,mps) ((drvr)->ep0configure(drvr,funcno,mps))
+#define DRVR_EP0CONFIGURE(drvr,funcaddr,mps) ((drvr)->ep0configure(drvr,funcaddr,mps))
/************************************************************************************
* Name: DRVR_ALLOC
@@ -465,7 +465,7 @@ struct usbhost_driver_s
* an external implementation of the enumeration logic.
*/
- int (*ep0configure)(FAR struct usbhost_driver_s *drvr, uint8_t funcno,
+ int (*ep0configure)(FAR struct usbhost_driver_s *drvr, uint8_t funcaddr,
uint16_t maxpacketsize);
/* Some hardware supports special memory in which transfer descriptors can
@@ -523,6 +523,7 @@ struct usbhost_epdesc_s
{
uint8_t addr; /* Endpoint address */
bool in; /* Direction: TRUE = IN */
+ uint8_t funcaddr; /* USB address of function containing endpoint */
uint16_t mxpacketsize; /* Max packetsize */
};
@@ -206,7 +206,7 @@
* drvr - The USB host driver instance obtained as a parameter from the call to
* the class create() method.
- * funcno - The USB address of the function containing the endpoint that EP0
+ * funcaddr - The USB address of the function containing the endpoint that EP0
* controls
* mps (maxpacketsize) - The maximum number of bytes that can be sent to or